
# Slot: slot with space 2




URI: [ks:subclassTest__slot_with_space_2](https://w3id.org/linkml/tests/kitchen_sink/subclassTest__slot_with_space_2)


## Domain and Range

None &#8594;  <sub>0..1</sub> [ClassWithSpaces](ClassWithSpaces.md)

## Parents


## Children


## Used by

 * [SubclassTest](SubclassTest.md)
